@@ -144,7 +144,7 @@ class DataVars(object):
         try:
             globals()[modVar] = __import__(modVar)
         except (ImportError, AttributeError), e:
-            err1 = _("Error in import module %s")%modVar
+            err1 = _("Error in importing module %s")%modVar
             err2 = _("error")  + ": " +str(e)
             raise self.DataVarsError("%s\n%s"%(err1,err2))
 
@@ -155,7 +155,7 @@ class DataVars(object):
             if "No module named" in str(e):
                 flagFindFillModule = False
             else:
-                err1 = _("Error in import module %s")%modFill
+                err1 = _("Error in importing module %s")%modFill
                 err2 = _("error")  + ": " +str(e)
                 raise self.DataVarsError("%s\n%s"%(err1,err2))
 
@@ -189,7 +189,7 @@ class DataVars(object):
             if dataVar is False:
                 dataVar = dataVarWork
         if dataVar == False:
-            err1 = _("Not found variable %s")%nameVar
+            err1 = _("Variable %s not found")%nameVar
             err2 = ""
             if e:
                 err2 = _("error")  + ": " +str(e)
@@ -215,7 +215,7 @@ class DataVars(object):
         """
         if not set(dictVar.keys()) <= set(dir(var)):
             raise self.DataVarsError(\
-                _("error initalize variable %s, incorrect data")%nameVar)
+                _("error in initalizing variable %s, incorrect data")%nameVar)
         for nameAttr in dictVar.keys():
             setattr(var, nameAttr, dictVar[nameAttr])
         return True
@@ -340,8 +340,8 @@ class DataVars(object):
             name_calculate_ini = ini_dict[location]
         else:
             cl_overriding.printERROR(\
-                _("Unable to find the alias '%s' of the file path for \
-storage of variables templates")%location)
+                _("Unable to find alias '%s' of the path to the file "
+                  "storing template variables templates")%location)
             cl_overriding.exit(1)
         return pathJoin(self.Get('cl_chroot_path'), name_calculate_ini)
 
@@ -354,7 +354,7 @@ storage of variables templates")%location)
             try:
                 self.Get(vname)
             except self.DataVarsError, e:
-                cl_overriding.printERROR(_("Not found template variable %s")\
+                cl_overriding.printERROR(_("Template variable %s not found")\
                                          %vname)
                 cl_overriding.printERROR(e)
                 cl_overriding.exit(1)
@@ -581,7 +581,8 @@ storage of variables templates")%location)
         try:
             value = self.Get(vname)
         except:
-            cl_overriding.printERROR(_("error var %s not found")%str(vname))
+            cl_overriding.printERROR(_("error, variable %s not found")%
+                                      str(vname))
             cl_overriding.exit(1)
         if value:
             return True
@@ -612,7 +613,7 @@ storage of variables templates")%location)
             try:
                 reFilter = re.compile("%s"%varsFilter)
             except:
-                cl_overriding.printERROR(_("wrong vars filter '%s'")\
+                cl_overriding.printERROR(_("wrong variable filter '%s'")\
                                          %str(varsFilter))
                 cl_overriding.exit(1)
         ret = {}
