@@ -278,23 +278,23 @@ class opt(optparse.OptionParser):
         [{'longOption':"set",
          'optVal':"VAR=VALUE",
          'action':'append',
-         'help':_("set value for variable")
+         'help':_("set the variable value")
         }]
     variable_view = \
         [{'shortOption':"v",
          'longOption':"show-variables",
          'action':'count',
-         'help':_("print variables, if the two options is verbose "
-                  "(added print hidden variables)")
+         'help':_("print variables, in verbose mode if the two options "
+                  "applied (includes printing hidden variables)")
         },
         {'longOption':"filter",
          'optVal':"FILTER",
-         'help':_("filtered variables by regular expression, \
-is used in conjunction with the options '-v --show-variables'")
+         'help':_("filter variables (as regexp, use *), to be used in"
+                  " conjunction with options '-v --show-variables'")
         },
         {'longOption':"xml",
-         'help':_("output variables in the format of XML, \
-is used in conjunction with the option '-v --show-variables'")
+         'help':_("output variables in XML format, to be used in"
+                  " conjunction with options '-v --show-variables'")
         }]
     variable_control = variable_set + variable_view
 
@@ -373,7 +373,8 @@ is used in conjunction with the option '-v --show-variables'")
         should either exit or raise an exception.
         """
         self.print_usage(sys.stderr)
-        self.exit(2, "%s: %s: %s\n%s\n" % (self.get_prog_name(), _("error"), msg,
+        self.exit(2, "%s: %s: %s\n%s\n" % (self.get_prog_name(),
+                                           _("error"), msg,
                 _("Try `%s' for more information")%
                 ("%s --help"%self.get_prog_name())))
 
