@@ -344,7 +344,8 @@ class tableReport:
             convLines.append(self._insertStrChar(lines[i], lenCols, char))
         cl_overriding.printSUCCESS("\n".join(convLines))
         if printRows:
-            cl_overriding.printSUCCESS("(%s %s)"%(len(self.dataList), _("rows")))
+            cl_overriding.printSUCCESS("(%s %s)"%
+                (len(self.dataList), _("rows")))
 
     def _insertStrChar(self, line, lenCols, char):
         """Вставляет несколько символов char в указанные позиции
