@@ -460,7 +460,7 @@ def str2dict(s):
             d[i] = replaceSlash(d[i])
         return d
     else:
-        cl_overriding.printERROR(_("wrong dict value: %s"%s))
+        cl_overriding.printERROR(_("wrong dictionary value: %s"%s))
         cl_overriding.exit(1)
 
 def str2list(s):
@@ -646,7 +646,8 @@ class SingletonParam(type):
     def __call__(cls,*args,**kw):
         keyarg = args[0] if args else ""
         if not keyarg in cls.instance:
-            cls.instance[keyarg] = super(SingletonParam, cls).__call__(*args, **kw)
+            cls.instance[keyarg] = \
+                super(SingletonParam, cls).__call__(*args, **kw)
         return cls.instance[keyarg]
 
 class FStab(object):
@@ -757,7 +758,7 @@ def getUserPassword(flag="dialog", pwDialog=False):
         if flag == "dialog":
             if not pwDialog:
                 pwDialog = [_("New password"),
-                            _("Retype new password")]
+                            _("Retype the new password")]
             pwdA = getpass.getpass(pwDialog[0]+":")
             pwdB = getpass.getpass(pwDialog[1]+":")
         elif flag == "stdin":
@@ -769,7 +770,7 @@ incorrect option 'flag=%s'")%flag)
             return False
         if not pwdA or not (pwdA == pwdB):
             cl_overriding.printERROR(_("ERROR") + ": " +\
-            _("password incorrect")+ ": " + _("try again"))
+            _("wrong password")+ ": " + _("try again"))
             return False
         userPwd = pwdA
         return userPwd
@@ -1353,3 +1354,30 @@ def getCmdLineParam(paramName):
         return params[-1]
     else:
         return ""
+
+def getSupportArch():
+    """Get supported architectures by processor.
+
+    Is support processor x86_64 else only i686.
+    """
+    if filter(lambda x:x.startswith('flags') and " lm " in x,
+        readLinesFile('/proc/cpuinfo')):
+        return ['i686','x86_64']
+    else:
+        return ['i686']
+
+def makeDirectory(pathname):
+    """Make directory and parent.
+
+    If directory exists then return False else True"""
+    try:
+        parent = path.split(path.normpath(pathname))[0]
+        if not path.exists(parent):
+            makeDirectory(parent)
+        else:
+            if path.exists(pathname):
+                return False
+        os.mkdir(pathname)
+        return True
+    except Exception, e:
+        return False
