@@ -103,6 +103,9 @@ class Data:
     # system (desktop or server)
     os_linux_system = {'hide':True}
 
+    # current timezone
+    os_clock_timezone = {'hide':True}
+
     # motherboard model
     hr_board_model = {'hide':True}
 
