@@ -51,7 +51,7 @@ def adminConnectLdap(fun):
             if self.clVars.defined("ld_base_dn"):
                 self.baseDN = self.clVars.Get("ld_base_dn")
             if not self.baseDN:
-                self.printERROR (_('Not found LDAP base DN'))
+                self.printERROR (_("Base DN not found for LDAP"))
         if flagError:
             return False
         else:
@@ -93,7 +93,7 @@ class ldapFunction(ldapFun):
                 return False
             return True
         else:
-            self.setError(_("No connect to LDAP server"))
+            self.setError(_("Unable to connect to the LDAP server"))
             return False
 
 
@@ -173,7 +173,7 @@ class shareldap(_error, color_print, shareVars):
             else:
                 service = part
             self.printERROR(\
-            _("Admin password for the service %s could not be found")%service)
+            _("Admin password for service %s could not be found")%service)
             return False
         ldapObj = ldapFunction(adminDn, adminPw)
         # Генератор задержек
@@ -194,7 +194,7 @@ class shareldap(_error, color_print, shareVars):
                 if not e in listError:
                     listError.append(e)
             _error.error = listError
-            self.printERROR (_("LDAP connect error") + ": " +\
+            self.printERROR (_("LDAP connection error") + ": " +\
                 ldapObj.getError().strip())
             return False
         # Устанавливаем у объекта соединение и объект LDAP функций
@@ -224,7 +224,7 @@ class shareldap(_error, color_print, shareVars):
                 if not e in listError:
                     listError.append(e)
             _error.error = listError
-            self.printERROR (_("LDAP connect error") + ": " +\
+            self.printERROR (_("LDAP connection error") + ": " +\
                 ldapObj.getError().strip())
             return False
         # Устанавливаем у объекта соединение и объект LDAP функций
@@ -408,7 +408,7 @@ class shareldap(_error, color_print, shareVars):
             # Код возврата
             retcode = pipe.wait()
             if retcode != 0:
-                self.printERROR(_("Can not convert file '%s' in jpeg format")\
+                self.printERROR(_("Cannot convert file '%s' in jpeg format")\
                                 %photoPath)
                 flagError = True
             fErr.close()
@@ -416,7 +416,7 @@ class shareldap(_error, color_print, shareVars):
                 photoData = fOut.read()
                 if not stringIsJpeg(photoData):
                     self.printERROR(\
-                    _("Can not convert file '%s' in jpeg format") %photoPath)
+                    _("Cannot convert file '%s' in jpeg format") %photoPath)
                     flagError = True
             fOut.close()
             if flagError:
