@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-__version__ = "2.2.24"
+__version__ = "2.2.25"
 __app__ = "calculate-lib"
 
 import sys, os, stat, re
@@ -218,7 +218,7 @@ class updateUserConfigs(shareUpdateConfigs):
                                              filter(lambda y: y, x.split(" "))),
                                              resWho))))))
         else:
-            self.printERROR(_("Can not execute 'who'"))
+            self.printERROR(_("Failed to execute 'who'"))
             return False
 
         return xUsers
@@ -245,7 +245,7 @@ class updateUserConfigs(shareUpdateConfigs):
                        set(self.getConfiguredPasswdUsers())))
         if not xUsers:
             self.logger.info(_("Package %s") %nameProgram)
-            self.logger.warn(_("Not found X sessions users"))
+            self.logger.warn(_("X sessions users not found"))
             return True
         self.logger.info(_("Package %s") %nameProgram)
         self.logger.info(_("Update desktop configuration files"))
@@ -273,7 +273,7 @@ class updateUserConfigs(shareUpdateConfigs):
                 dirsFiles = clTempl.applyTemplates()
                 if dirsFiles is False:
                     self.printERROR(\
-                        _("Error using templates for the user %s")\
+                        _("Error in using templates for the user %s")\
                             %userName)
                     for errMess in clTempl.getError().splitlines():
                         self.printERROR(errMess)
@@ -288,14 +288,15 @@ class updateUserConfigs(shareUpdateConfigs):
                         sorted(list(set(dirsFiles[1])))))
             if dictPakkages:
                 for calcPkg in listIndex:
-                    self.printWARNING(_("Package %s has changed files")\
+                    self.printWARNING(
+                        _("Package %s has changed the following files")\
                                       %calcPkg+":")
                     for userName, configFiles in dictPakkages[calcPkg]:
                         self.printWARNING(" "*2 + _("User %s")%userName + ":")
                         for nameConfigFile in configFiles:
                             self.printWARNING(" "*5 + nameConfigFile)
         if not dictPakkages:
-             self.logger.warn(_("Not found templates"))
+             self.logger.warn(_("Templates not found"))
         return True
 
 class updateSystemConfigs(shareUpdateConfigs):
@@ -367,7 +368,7 @@ class updateSystemConfigs(shareUpdateConfigs):
         """Копирование конфигурационных файлов"""
         configDstFiles = self.scanProtectDirs(configPath)
         if configDstFiles:
-            self.logger.warn(_("Replace files:"))
+            self.logger.warn(_("Replaced files:"))
         for dst in configDstFiles:
             src = pathJoin(configPath, dst)
             if src != dst:
@@ -435,7 +436,7 @@ class updateSystemConfigs(shareUpdateConfigs):
             dirsFiles = clTempl.applyTemplates()
             nameAndVerPkg = nameProg + "-"+clVars.Get("cl_ver")
             if dirsFiles is False:
-                self.printERROR(_("Error template in a package %s")\
+                self.printERROR(_("Template error in package %s")\
                                 %nameAndVerPkg)
                 for errMess in clTempl.getError().splitlines():
                     self.printERROR(errMess)
@@ -453,7 +454,8 @@ class updateSystemConfigs(shareUpdateConfigs):
                     sorted(list(set(dirsFiles[1])))
         if dictPakkages:
             for calcPkg in listIndex:
-                self.printWARNING(_("Package %s has changed files")%calcPkg+":")
+                self.printWARNING(
+                    _("Package %s has changed the following files")%calcPkg+":")
                 for nameF in dictPakkages[calcPkg]:
                     nameFile = nameF.partition(configPath)[2]
                     if nameFile:
@@ -463,7 +465,7 @@ class updateSystemConfigs(shareUpdateConfigs):
                         nameFile = nameF
                     self.printWARNING(" "*5 + nameFile)
         else:
-            self.logger.warn(_("Not found templates"))
+            self.logger.warn(_("Templates not found"))
         if flagUpdate:
             self.copyConfigFiles(configPath)
         if clTempl and clTempl.getWarning():
